import { Method } from 'axios';
import { Executable } from './executable';
import { Order } from './get-tokens';
/**
 * The GetOrdersInput used by the constructor of GetOrders
 */
export interface GetOrdersInput {
    /**
     * The orderId to retrieve a specific order.
     */
    orderId?: number;
    /**
     * The bambu personId for identifying a person.
     */
    personId?: string;
    /**
     * The email address of the person.
     */
    email?: string;
}
/**
 * The GetOrders response expected from the execution of the object within BambuClient execute.
 */
export interface GetOrdersResponse {
    /**
     * the message response from the request
     */
    orders: Order[];
    /**
     * any error messages that were returned by the request.
     */
    error?: any;
}
/**
 * The get order api is a retrieves the list of orders created for the provided person.
 */
export declare class GetOrders extends Executable<GetOrdersResponse> {
    orderId?: number;
    personId?: string;
    email?: string;
    /**
     * getMethod is used by the BambuClient to properly construct the request call.
     * @returns request method
     */
    getMethod(): Method;
    /**
     * getResponse is used by the BambuClient to propery return the response object type.
     * @param apiResponse the api response object returned by the BambuMeta client before being converted to the GetOrderResponse
     * @returns GetOrderResponse
     */
    getResponse(apiResponse: any): GetOrdersResponse;
    /**
     * getURLPath is used by the BambuClient to properly construct the request call.
     * @param tenantId the tenant id defined in the BambuClient
     * @returns request url
     */
    getURLPath(tenantId?: string): string;
    constructor(input?: GetOrdersInput);
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): any;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
