import { Method } from 'axios';
import { Executable } from './executable';
import { WalletPass } from './interfaces';
/**
 * The input object to the GetWallet class constructor.
 */
export interface GetWalletInput {
    /**
     * The email of the wallet
     */
    email?: string;
    /**
     * The program ID the wallet belongs to.
     */
    programId?: number;
    /**
     * The brand ID the wallet belongs to.
     */
    brandId?: number;
    /**
     * The pass id of the wallet card.
     */
    passId?: number;
}
/**
 * Creates a product for the provided tenant to be able to generate and mint NFTs from.
 */
export declare class GetWallet extends Executable<WalletPass> {
    /**
     * getMethod is used by the BambuClient to properly construct the request call.
     * @returns request method
     */
    getMethod(): Method;
    /**
     * getResponse is used by the BambuClient to propery return the response object type.
     * @param apiResponse the api response object returned by the BambuMeta client before being converted to the GetWalletResponse
     * @returns GetWalletResponse
     */
    getResponse(apiResponse: any): WalletPass;
    /**
     * getURLPath is used by the BambuClient to properly construct the request call.
     * @param tenantId the tenant id defined in the BambuClient
     * @returns request url
     */
    getURLPath(tenantId?: string): string;
    /**
     * The pass id of the wallet card.
     */
    passId?: number;
    /**
     * The program ID the wallet belongs to.
     */
    programId?: number;
    /**
     * The brand ID the wallet belongs to.
     */
    brandId?: number;
    /**
     * The email of the wallet
     */
    email?: string;
    constructor(input?: GetWalletInput);
    /**
     * Sets the email of the person
     * @param value The email of the person
     * @returns <GetWallet>
     */
    setEmail(value: string): GetWallet;
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): any;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
