/**
 * A link activation record that is configured to issue wallet cards for a program.
 */
export interface ILinkActivation {
    /**
     * The link activation unique identifier.
     */
    linkActivationId: number;
    /**
     * The tenant unique identifier.
     */
    tenantId: number;
    /**
     * The brand unique identifier.
     */
    brandId: number;
    /**
     * The program unique identifier.
     */
    programId: number;
    /**
     * A name for the link activation record.
     */
    name: string;
    /**
     * Is captcha enabled for this link activation record.
     */
    captchaEnabled: boolean;
    /**
     * The expiration date of this link activation.
     */
    endDate: Date | string;
    /**
     * An external identifier that is generated for this link activation.
     */
    externalIdentifier: string;
    /**
     * The number of times this link activation has been accessed
     */
    accesses: number;
    /**
     * The number of times this link activation has issued a card.
     */
    emissions: number;
    /**
     * The number of times this link activation can be used to issue a card.
     */
    passesLimit: number;
    /**
     * The tier identifier to issue this link activation for, if defined.
     */
    templateTierId?: number;
    /**
     * The attributes that are associated to the link activation.
     */
    attributes: ILinkActivationAttribute[];
}
/**
 * The ILinkActivationAttribute object, maintains link activation attribute configuration and details.
 */
export interface ILinkActivationAttribute {
    /**
     * The queryString attribute used for this attribute.
     */
    queryString: string;
    /**
     * Is this attribute required for link activation?
     */
    required: boolean;
    /**
     * The attribute name, must match the name of the attribute in the template.
     */
    name: string;
    /**
     * The path this attribute is mapped to in the issue-wallet input.
     */
    path: string;
    /**
     * The datatype of this attribute.
     */
    dataType?: string;
}
/**
 * The ILinkActivationInput object, maintains link activation configuration and details.
 * This is the input object for creating a link activation.
 */
export type ILinkActivationInput = Omit<ILinkActivation, 'linkActivationId' | 'externalIdentifier' | 'accesses' | 'emissions'>;
