import { Method } from 'axios';
import { Executable } from '../executable';
import { ILinkActivation, ILinkActivationAttribute, ILinkActivationInput } from '..';
/**
 * The CreateLinkActivation creates an activation link for a program to issue cards with.
 */
export declare class CreateLinkActivation extends Executable<ILinkActivation> implements Partial<ILinkActivationInput> {
    name?: string;
    brandId?: number;
    tenantId?: number;
    programId?: number;
    endDate?: Date | string;
    templateTierId?: number;
    attributes?: ILinkActivationAttribute[];
    captchaEnabled?: boolean | undefined;
    passesLimit?: number | undefined;
    getMethod(): Method;
    getResponse(apiResponse: any): ILinkActivation;
    getURLPath(tenantId?: string): string;
    constructor(input?: Partial<ILinkActivationInput>);
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): Partial<ILinkActivationInput> & {
        tenantId: number;
        name: string;
    };
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
