/// <reference types="node" />
/// <reference types="node" />
import { Method } from 'axios';
import { Executable } from '../executable';
import { BambuProgram, BambuProgramInput, ProgramStatusCode } from '../interfaces';
/**
 * The CreateProgramInput used by the constructor of CreateProgram
 */
export declare class CreateProgram extends Executable<BambuProgram> implements Partial<BambuProgramInput> {
    name?: string;
    abbreviation?: string;
    brandId?: number;
    tenantId?: number;
    templateId?: number;
    logo?: string;
    color?: string;
    statusCode?: ProgramStatusCode;
    imageFile?: string | Buffer;
    getMethod(): Method;
    getResponse(apiResponse: any): BambuProgram;
    getURLPath(tenantId?: string): string;
    constructor(input?: Partial<BambuProgramInput> & {
        tenantId: number;
        brandId: number;
        name: string;
    });
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): Partial<BambuProgramInput> & {
        tenantId: number;
        name: string;
    };
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
