import { Method } from 'axios';
import { Executable, IPrepareRequestOptions } from '../executable';
import { IWalletTemplateCreateInput, IWalletTemplatePassData, IWalletTemplateAndroidPassData, IWalletTemplateFieldMapping, BambuPassStyles } from '../interfaces/wallet-template';
/**
 * The IWalletTemplateCreateResponse returns the templateId and possibly a message after creation.
 */
export interface IWalletTemplateCreateResponse {
    templateId: number;
    message: string;
}
/**
 * The IWalletTemplateCreateExtendedInput collects the Wallet Template details and the brandId and programIds used to construct the wallet template.
 */
export interface IWalletTemplateCreateExtendedInput extends IWalletTemplateCreateInput {
    brandId: number;
    programId: number;
}
/**
 * CreateWalletTemplate is the executable class for creating a wallet template.
 * @param input IWalletTemplateCreateExtendedInput
 * @returns The templateId and possibly a message after creation.
 */
export declare class CreateWalletTemplate extends Executable<IWalletTemplateCreateResponse> implements Partial<IWalletTemplateCreateExtendedInput> {
    brandId?: number;
    programId?: number;
    name?: string;
    organizationName?: string;
    sharingProhibited?: boolean;
    sharingUrl?: string;
    passdata?: IWalletTemplatePassData;
    androidPassData?: IWalletTemplateAndroidPassData;
    fieldMappings?: IWalletTemplateFieldMapping[];
    walletIdentifierId?: number;
    defaultMessage?: string;
    getMethod(): Method;
    prepareRequest({ execute }: IPrepareRequestOptions): Promise<any>;
    getResponse(apiResponse: any): IWalletTemplateCreateResponse;
    getURLPath(tenantId?: string): string;
    constructor(input?: Partial<IWalletTemplateCreateExtendedInput> & {
        tenantId: number;
        name: string;
    });
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): Partial<IWalletTemplateCreateExtendedInput>;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
export { BambuPassStyles };
