import { Method } from 'axios';
import { Executable } from '../executable';
import { BambuBrand, BambuBrandUIConfig } from '../interfaces/brands';
/**
 * This class is used to construct the input to update a brand.  The inputs can either be provided as
 * part of the constructor, or set after the fact in the public properties.
 *
 * BrandId is required to update the brand.
 */
export declare class UpdateBrand extends Executable<BambuBrand> implements Partial<BambuBrand> {
    brandId?: number;
    name?: string;
    description?: string;
    tenantId?: number;
    logo?: string;
    reportSite?: string;
    uiConfig?: BambuBrandUIConfig;
    getMethod(): Method;
    getResponse(apiResponse: any): BambuBrand;
    getURLPath(tenantId?: string): string;
    constructor(input?: Partial<BambuBrand> & {
        brandId: number;
    });
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): Partial<BambuBrand>;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
