import { Method } from 'axios';
import { Executable } from './executable';
/**
 * The Update Wallet Input used by the constructor of Update Wallet Notification.  Either personId or email are required to identify the wallet.
 */
export interface UpdateWalletNotificationInput {
    /**
     * Bambu person identifier
     */
    personId?: string;
    /**
     * Card Serial Number
     */
    serialNumber?: string;
    /**
     * Card Pass Identifier
     */
    passId?: number;
}
/**
 * The UpdateWalletNotification response expected from the execution of the object within BambuClient execute.
 */
export interface UpdateWalletNotificationResponse {
    /**
     * the message response from the request
     */
    message: string;
    /**
     * any error messages that were returned by the request.
     */
    error?: any;
    /**
     * If the person already exists, the personId is returned.
     */
    successful: boolean;
}
/**
 * The Update Wallet message takes a personId or email address and a message and uses that information to identify an existing wallet card within the tenant.  Then the message field on the card is udpated.
 */
export declare class UpdateWalletNotification extends Executable<UpdateWalletNotificationResponse> {
    /**
     * getMethod is used by the BambuClient to properly construct the request call.
     * @returns request method
     */
    getMethod(): Method;
    /**
     * getResponse is used by the BambuClient to propery return the response object type.
     * @param apiResponse the api response object returned by the BambuMeta client before being converted to the UpdateWalletNotificationResponse
     * @returns UpdateWalletNotificationResponse
     */
    getResponse(apiResponse: any): UpdateWalletNotificationResponse;
    /**
     * getURLPath is used by the BambuClient to properly construct the request call.
     * @param tenantId the tenant id defined in the BambuClient
     * @returns request url
     */
    getURLPath(tenantId?: string): string;
    private _personId?;
    private _serialNo?;
    private _passId?;
    constructor(input?: UpdateWalletNotificationInput);
    /**
     * Sets the personId on the person.
     * @param value <string> person id
     * @returns <UpdateWalletNotification>
     */
    setPersonId(value: string): UpdateWalletNotification;
    /**
     * Sets the serial number card.
     * @param value <string> email
     * @returns <UpdateWalletNotification>
     */
    setSerialNo(value: string): UpdateWalletNotification;
    /**
     * Sets the card passId
     * @param value <number> wallet card id.
     * @returns <UpdateWalletNotification>
     */
    setPassId(value: number): UpdateWalletNotification;
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): any;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
