import { Method } from 'axios';
import { GeoLocation, WalletPass, WalletPassData, WalletPassInput, WalletPerson } from './interfaces';
import { Executable } from './executable';
/**
 * Updates an existing wallet pass either by the pass identifier or the email address used on the pass and the program identifier.
 */
export declare class UpdateWallet extends Executable<WalletPass> implements Partial<WalletPassInput> {
    /**
     * The brand identifier.
     */
    brandId?: number;
    /**
     * The program identifier.
     */
    programId?: number;
    /**
     * The pass identifier. Optional if either email + programId or uniqueId + programId are provided
     */
    passId?: number;
    /**
     * The email address used on the pass. Optional if either passId or uniqueId are provided.
     */
    email?: string;
    /**
     * The unique identifier used on the pass. Optional if either passId or email are provided.
     */
    uniqueId?: string;
    passdata?: WalletPassData;
    /**
     * The person record.
     */
    person?: WalletPerson;
    /**
     * The current message that is displayed on the wallet pass.
     */
    currentMessage?: string;
    /**
     * The tier to put the card in during creation, if not provided will use the default tier.
     */
    templateTierId?: number;
    /**
     * The location from which the card is being issued.
     */
    geoLocation?: GeoLocation;
    /**
     * The ipaddress which is requesting the card to be issued.
     */
    ipAddress?: string;
    /**
     * The templateId from which the card is being issued.  If a program is provided, this is not required.
     */
    templateId?: number;
    dynamicImageUrl?: string;
    getMethod(): Method;
    getResponse(apiResponse: any): WalletPass;
    getURLPath(tenantId?: string): string;
    constructor(input?: Partial<WalletPassInput> & {
        brandId: number;
    });
    /**
     * getBody is used by the BambuClient to properly construct the request object body.
     * @returns Returns the expected body of the request utilizing the defined request attributes.
     */
    getBody(): Partial<WalletPassInput>;
    /**
     * getRootPath is used by the BambuClient to properly construct the request call.
     * @returns The root path of the request
     */
    getRootPath(): string | undefined;
}
